% ---------------- Praktische Umsetzung zur Masterarbeit -----------------
% ------------------------------------------------------------------------
% --- "Beitrag zur Ermittlung des Bodensignals zur verbesserten ----------
% ----  Ableitung des Vegetationssignals aus Fernerkundungsdaten " -------
% ------------------------------------------------------------------------
% 
% Stand:    03.03.2017
% Autor:    Sophie Khnlenz
%
% ------------------------------------------------------------------------
% 
%   - Laufzeitumgebung: 
%           Die Hautpdatei muss innerhalb des Verzeichnisses MATLAB 
%           aufgerufen werden und bezieht sich auf weitere Skripte im 
%           Verzeichnis "functions".
% 
%   - Eingangsdaten:
%           Der Prozess nimmt eine Auswertung der HySpex-Daten vor, die im
%           Verzeichnis "data" liegen. Die Auswertung anderer Daten  
%           erfordert eine Anpassung von "getPath()" und gegebenenfalls der  
%           Routinen zum Auslesen der Metadaten aus der Header-Datei. 
%           Darber hinaus kann die Anpassung des berlappungsbereichs mit 
%           "correctSpecBands()" entfallen.
% 
% ------------------------------------------------------------------------

addpath(genpath('functions\'), genpath('data\'));

subset      = 1; % 1 = Schlag 1, 2 = Schlag 2, 3 = Schlag 3
M           = 2; % Filterlnge des Savitzky-Golay Filters
P           = 2; % Polynomgrad des Savitzky-Golay Filters
binBW       = 0.016; % Angestrebte Bandbreite beim Binning
sw          = 0.1; % Empirischer Hilfswert fr die Binrbilderzeugung
trackGeom   = [0.7 3 36]; % Parameter des Fahrspurmodells [t1 t2 t3]
S           = 11; % Skalierungsfaktor bei der Flchenabschtzung
opt         = 2; % 1 = Optimierungsansatz 1, 2 = Optimierungsansatz 2
N           = 21; % Pixelanzahl des Spektralmodells

% (0) DATEN LADEN --------------------------------------------------------
[data, RGB, WL, FWHM, GSD, RSF]  = loadData(subset);

% (1) VORVERARBEITUNG ---------------------------------------------------- 
% (1.1) Spektrale Glttung
[data, WL, FWHM] = spectralSmooth(data, WL, FWHM, M, P);
% (1.2) Binning 
[data, WL, FWHM] = dataReduction(data, WL, FWHM, binBW);

% (2) SEGMENTIERUNG DES UNTERSUCHUNGSGEBIETS (manuell im Voraus) ---------

% (3) SELEKTION DER FAHRGASSEN -------------------------------------------
% (3.1) Erzeugung eines binren Kantenbildes 
[imgBW, imgGray]    = edgeDetection(data, WL, RSF, trackGeom, sw, GSD, 0);
% (3.2) Detektion der gesuchten Strukturen
[trackLines, alpha] = getTracks(subset, imgBW, imgGray, trackGeom, GSD, 0);

% (4) ENTMISCHUNG DER FAHRGASSENPIXEL ------------------------------------
% (4.1) Abschtzung der Abundanzen
[imgTrackArea, tracks]  = geomAnalysis(data, trackLines, trackGeom, ...
                                GSD, S, alpha, 0);
% (4.1) Ermittlung des Bestandsreferenzsignals
[imgVeg, imgTrack]      = getRefPlantSpec(data, trackLines, ...
                                imgTrackArea, RGB, trackGeom, GSD, WL, 0);
% (4.2) Ableitung des Bodensignals
imgSoil = getSoilSpec(data, imgVeg, imgTrackArea, opt, N, 0);
