function [corData, corWL, corFWHM] = correctSpecBands(data, WL, FWHM)

    % Funktion
    %   berprfung der Daten auf berlappungsbereich und Entfernung 
    %   berschssiger Bnder. 
    % 
    % Eingabe
    %   - data:             Subset-Nummer
    %   - WL:               Wellenlngen der Spektralbnder
    %   - FWHM:             Bandbreiten der Spektralbnder
    %
    % Ausgabe
    %   - corData:          Korrigierte Hyperspektraldaten
    %   - corWL:            Korrigierte Wellenlngen der Spektralbnder
    %   - corFWHM:          Korrigierte Bandbreiten der Spektralbnder

    memWL                   = 0;
    corWL{1}                = [];
    corFWHM{1}              = [];
    [lines, samples, bands] = size(data);
    corData                 = zeros(lines, samples);
    
    for k=1:length(WL{1})-1
        curWL   = WL{1}(k);
        nextWL  = WL{1}(k+1);
        if(nextWL < curWL)
            memWL = curWL;
            corWL{1}(end+1)         = curWL;
            corFWHM{1}(end+1)       = FWHM{1}(k);
            if(k == 1)
                corData(:, :, 1)    = data(:, :, k);
            else                
                corData(:, :, end+1)    = data(:, :, k);
            end
        else
            if(memWL == 0)                
                corWL{1}(end+1)         = curWL;
                corFWHM{1}(end+1)       = FWHM{1}(k);
                if(k == 1)
                    corData(:, :, 1)    = data(:, :, k);
                else                
                    corData(:, :, end+1)    = data(:, :, k);
                end
            end
        end
        if(memWL ~= 0 && memWL < curWL)
            memWL = 0;
            corWL{1}(end+1)         = curWL;
            corFWHM{1}(end+1)       = FWHM{1}(k);
            corData(:, :, end+1)    = data(:, :, k);
        end        
    end    
    if(memWL == 0)
        corWL{1}(end+1)         = nextWL;
        corFWHM{1}(end+1)       = FWHM{1}(k+1);
        corData(:, :, end+1)    = data(:, :, k+1);
    end
    corWL{1}      = corWL{1}';
    corFWHM{1}    = corFWHM{1}';
    
end