function [WL, FWHM, defBands] = getBands(header)

    % Funktion
    %   Auslesen der Wellenlngen und Bandbreiten der Spektralbnder sowie
    %   der Default-Bnder zur RGB-Darstellung.
    % 
    % Eingabe
    %   - header:           Dateipfad der Header-Datei
    %
    % Ausgabe
    %   - WL:               Wellenlngen der Spektralbnder
    %   - FWHM:             Bandbreiten der Spektralbnder
    %   - defBands:         Default-Bnder zur RGB-Darstellung

    % Wellenlngen -------------------------------------------------------
    fileNameW = 'wavelength.txt';
    fileNameF = 'fwhm.txt';
    fileIDw   = fopen(fileNameW,'wt');
    fileIDf   = fopen(fileNameF,'wt');
    fileID    = fopen(header);
    saveW     = 0;
    saveF     = 0;
    defBndStr = 'default bands = {';
    startStr  = 'wavelength = {';
    stopStr   = 'fwhm = {';
    
    while ~feof(fileID)
        line = fgetl(fileID);
        if(findstr(defBndStr, line))
            lineDB = line(length(defBndStr)+1:end-1);
            defBands  = textscan(lineDB,'%d', 'Delimiter',',');
        end
        if(saveF)
            if(findstr('}', line))
                x = findstr('}', line)-1;
                line = line(1:x);
                saveF = 0;
            end
            fprintf(fileIDf, [line '\n']);
        end     
        if(strcmpi(line, stopStr))
            saveW = 0;
            saveF = 1;
        end
        if(saveW)
            if(findstr('}', line))
                x = findstr('}', line)-1;
                line = line(1:x);
            end
            fprintf(fileIDw, [line '\n']);
        end    
        if(strcmpi(line, startStr))
           saveW = 1; 
        end       
    end
    fclose(fileIDw);
    fclose(fileIDf);
        
    % Wellenlngen einlesen
    fileIDW     = fopen('wavelength.txt');
    WL  = textscan(fileIDW,'%.6f', 'Delimiter',',');

    % Bandbreiten einlesen
    fileIDF     = fopen('fwhm.txt');
    FWHM        = textscan(fileIDF,'%.6f', 'Delimiter',','); 
    
    fclose(fileIDw);
    fclose(fileIDf);
    delete(fileNameW);
    delete(fileNameF);
    
end