function [RGB] = getRGBReference(data, defBands)

    % Funktion
    %   Erzeugung einer RGB-Darstellung des Subset.
    % 
    % Eingabe
    %   - data:             Hyperspektraldaten
    %   - defBands:         Default-Bnder zur RGB-Darstellung
    %
    % Ausgabe
    %   - RGB:              RGB-Darstellung

    % Dimension
    [rows, cols, c] = size(data);
    
    % Zuweisung der Kanle
    imgRed      = data(:, :, defBands{1}(1));
    imgGreen    = data(:, :, defBands{1}(2));
    imgBlue     = data(:, :, defBands{1}(3));

    % Maximaler Pixelwert aller 3 Kanle
    maxVals     = [max(imgRed(:)), max(imgGreen(:)), max(imgBlue(:))];
    maxRGB      = max(maxVals);

    % Skalierung des Wertebereichs auf [0, 1]
    imgRedSC = imgRed./(maxRGB/1);
    imgGreenSC = imgGreen./(maxRGB/1);
    imgBlueSC = imgBlue./(maxRGB/1);

    % Kontrastausgleich    
    imgRedSC = imadjust(imgRedSC);
    imgGreenSC = imadjust(imgGreenSC);
    imgBlueSC = imadjust(imgBlueSC);

    % Zusammensetzung RGB-Referenz
    RGB = zeros(rows, cols, 3);
    RGB(:, :, 1) = imgRedSC;
    RGB(:, :, 2) = imgGreenSC;
    RGB(:, :, 3) = imgBlueSC;
   
end