function [corData, RGB, corWL, corFWHM, GSD, RSF] = loadData(subset)  

    % Funktion
    %   Laden des Hyperspektraldatenblocks, sowie Auslesen einiger
    %   Metadaten. Im Spezialfall der gegebenen HySpex-Daten erfolgt 
    %   zudem eine Entfernung des berlappungsbereichs der beiden Sensoren.
    % 
    % Eingabe
    %   - subset:           Subset-ID
    %
    % Ausgabe
    %   - corData:          Korrigierte Hyperspektraldaten
    %   - RGB:              RGB-Darstellung des Subset
    %   - corWL:            Korrigierte Wellenlngen der Spektralbnder
    %   - corFWHM:          Korrigierte Bandbreiten der Spektralbnder
    %   - GSD:              Bodenauflsung
    %   - RSF:              Reflexionsskalierungsfaktor
    
    
    % DATEIEN ------------------------------------------------------------
    [file, header]                  = getPath(subset);
    
    % HEADER INFOS -------------------------------------------------------
    % Dimension
    [lines, samples, bands]         = getDimension(header);
    % Wellenlngen, Mittlere Bandbreiten und Default-Bnder fr RGB
    [wavelength, fwhm, defBands]    = getBands(header);
    % Bodenauflsung
    [GSD]                           = getGSD(header);
    % Reflectance Scale Factor
    [RSF]                           = getRSF(header);

    % DATEN --------------------------------------------------------------
    data                            = multibandread(file, [lines, samples, ...
                                        bands], 'int16', 0, 'bsq', 'ieee-le');     

    % berprfung und Korrektur der Spektralbnder -----------------------
    [corData, corWL, corFWHM]       = correctSpecBands(data, wavelength, fwhm); 

    % RGB-REFERENZ -------------------------------------------------------
    RGB                             = getRGBReference(data, defBands);
    
end