function [reducedData, WL2, FWHM2] = dataReduction(data, WL, FWHM, binBW)

    % Funktion
    %   Datenreduktion via Binning fr die neue Bandbreite binBW. 
    % 
    % Eingabe
    %   - data:             Hyperspektraldaten
    %   - WL:               Wellenlngen der Spektralbnder
    %   - FWHM:             Breite der Spektralbnder
    %   - binBW:            Neue Bandbreite
    %
    %
    % Ausgabe
    %   - reducedData:      Reduzierte Daten
    %   - WL2:              Angepasste Wellenlngen der Spektralbnder
    %   - FWHM2:            Angepasste Breiten der Spektralbnder

    disp('Binning')
    tic
    
    [lines, samples, bands] = size(data);
    reducedData             = zeros(lines, samples, bands);
    sum                     = 0;
    numb                    = 0;
    idx                     = [];
    FWHM2{1}                = [];
    WL2{1}                  = [];

    for k=1:length(WL{1})
        % Zusammenfassung aufeinanderfolgender Bandbreiten
        bw          = FWHM{1}(k);
        sum         = sum + bw;
        idx(end+1)  = k;
        if(sum >= binBW)   
           numb = numb + 1;
           % Grenzen der neuen Bnder
           bs = WL{1}(idx(1)) - FWHM{1}(idx(1))/2;
           be = WL{1}(idx(end)) + FWHM{1}(idx(end))/2;
           % Zentren der neuen Bnder
           WL2{1}(end+1, 1)    = (bs + be)/2;
           % Bandbreiten
           FWHM2{1}(end+1, 1)          = be - bs;
           % Mittelung der neuen Bnder
           sumOfBands = 0;
           for i=1:length(idx)           
               sumOfBands = sumOfBands + data(:, :, idx(i));           
           end       
           band_2             = sumOfBands/length(idx);
           reducedData(:, :, numb) = band_2;
           sum = 0;
           idx = [];      
       end
    end
    reducedData    = reducedData(:, :, 1:numb);
    toc
end