function [smoothedData, WL2, FWHM2] = spectralSmooth(data, WL, FWHM, M, P)

    % Funktion
    %   Spektrale Glttung der Eingangsdaten mit dem Savitzky-Golay Filter
    %   unter Verwendung der Filtergrer M und dem Polynomgrad P.
    % 
    % Eingabe
    %   - data:             Hyperspektraldaten
    %   - WL:               Wellenlngen der Spektralbnder
    %   - FWHM:             Breite der Spektralbnder
    %   - M:                Filterlnge des Savitzky-Golay Filters
    %   - P:                Polynomgrad des Savitzky-Golay Filters
    %
    % Ausgabe
    %   - smoothedData:     Geglttete Daten
    %   - WL2:              Angepasste Wellenlngen der Spektralbnder
    %   - FWHM2:            Angepasste Breiten der Spektralbnder

    disp('Spektrale Glttung')
    tic

    [lines, samples, bands]     = size(data);
    smoothedData                = zeros(lines, samples, bands-2*M);
    smoothedData(1:end, 1:end)  = -1;
    
    % Entfernung der ersten und letzten Werte
    WL2{1}     = WL{1}(1+M:end-M);
    FWHM2{1}   = FWHM{1}(1+M:end-M);
    
    % Design-Matrix
    A = [];                
    for basis=-M:M
        row = [];
        for exp=0:P
            term = basis^exp;
            row = [row term];
        end
        A = [A; row];
    end                
    H   = inv(A'*A)*A';
    H0  = H(1, :);
                
    for l=1:lines
        for s=1:samples    
            val = data(l, s, 1);
            % Innerhalb der Maske?
            if(val ~= -1)
               % Pixelspektrum
               pixSpec = squeeze(data(l, s, :));               
               % Polynomiale Glttung
               smoothedPixSpec  = [];
               x                = [];               
               for k=1+M:length(pixSpec)-M    
                   x                = pixSpec(k-M:k+M);
                   x0_new           = H0*x;                  
                   smoothedPixSpec  = [smoothedPixSpec; x0_new];                   
               end
               smoothedData(l, s, :) = smoothedPixSpec;                
            end
        end    
    end
    toc
end