function [imgBW2, imgENH2] = edgeDetection(data, WL, RSF, trackGeom, sw, GSD, p)
    
    % Funktion
    %   Erzeugung eines binren Kantenbildes unter Verwendung der NDVI- 
    %   und NDSI-Auswertung.
    % 
    % Eingabe
    %   - data:             Hyperspektraldaten
    %   - WL:               Wellenlngen der Spektralbnder
    %   - RSF:              Skalierungsfaktor der Reflexionswerte
    %   - trackGeom:        Parameter des Fahrspurmodells
    %   - sw:               Empirischer Wert zur Schwellwertberechnung
    %   - GSD:              Bodenauflsung    
    %   - p:                Flag zum Plotten (1 = ja, 0 = nein)
    %
    % Ausgabe
    %   - imgBW2:           Binres Kantenbild (NDSI)
    %   - imgENH2:          Grauwertbild (NDSI)

    disp('Erzeugung des binren Kantenbildes')
    tic

    % (1) NDVI + NDSI invertiert (hoher Kontrast) ------------------------
    imgNDVI     = getNDVI(data, WL);  
    img1        = imcomplement(imgNDVI);    
    imgNDSI     = getNDSI(data, WL);
    img2        = imcomplement(imgNDSI);    
    
    if(p)
        figure(1)
        subplot(1, 2, 1)
        imagesc(img1), axis image off, colormap gray, title('NDVI')
        subplot(1, 2, 2)
        imagesc(img2), axis image, colormap gray, title('NDSI') 
    end
       
    % (2) LOKALER SELEKTIONSFILTER ---------------------------------------
    imgENH          = enhanceHighlights(img1, RSF, GSD, trackGeom); 
    imgENH2         = enhanceHighlights(img2, RSF, GSD, trackGeom); 
   
    if(p)
        figure(2)
        subplot(1, 2, 1)
        imagesc(imgENH), axis image, colormap gray, title('NDVI')
        subplot(1, 2, 2)
        imagesc(imgENH2), axis image, colormap gray, title('NDSI')
    end
             
    % (3) SCHWELLWERTBILDUNG ---------------------------------------------
    imgBW           = thresholding(data, imgENH, sw, RSF);   
    imgBW2          = thresholding(data, imgENH2, sw, RSF);
        
    if(p)
        figure
        subplot(1, 2, 1)
        imagesc(imgBW), axis image, colormap gray, title('NDVI')
        subplot(1, 2, 2)
        imagesc(imgBW2), axis image, colormap gray, title('NDSI')
    end        
    toc    
end

