function [imgENH] = enhanceHighlights(img, RSF, GSD, trackGeom)

    % Funktion
    %   Filterung des Eingabebildes img zur Verstrkung der hellsten Pixel
    %   im Bild.
    % 
    % Eingabe
    %   - img:          Eingabebild
    %   - RSF:          Skalierungsfaktor der Reflexionswerte
    %   - GSD:          Bodenauflsung
    %   - trackGeom:    Parameter des Fahrspurmodells
    %
    % Ausgabe
    %   - imgENH:       Ausgabebild
    
    imgENH      = zeros(size(img));
    t3          = trackGeom(3)/GSD;
    
    % Bestimmung der Filtergre
    if(mod(t3, 2) == 0)
        % gerade
        N0 = t3-1;
    else
        % ungerade
        N0 = t3-2;
    end
    N = (N0-1)/2;   
    
    for y=1+N:size(img, 1)-N
        for x=1+N:size(img, 2)-N
            patch   = img(y-N:y+N, x-N:x+N);
            medVal  = median(patch(:));
            minVal  = min(patch(:));
            maxVal  = max(patch(:));
            % Filter A
%             curVal  = (img(y, x) - minVal)/(maxVal-minVal);
            % Filter B
            curVal  = (img(y, x)-medVal)/(maxVal-minVal);            
            % Filter C
%             curVal  = (maxVal - medVal)/(maxVal-minVal);
            if(curVal < 0)
                imgENH(y, x) = 0;
            else            
                imgENH(y, x) = curVal*RSF;
            end
        end
    end
    
end