function [hist, counter] = getHistogram(img, imgRef, RSF)

    % Funktion
    %   Histogramm-Berechnung fr das Eingabebild und Bestimmung der
    %   Pixelanzahl des segmentierten Untersuchungsgebiets.
    % 
    % Eingabe
    %   - img:          Eingabebild
    %   - imgRef:       Referenzmatrix
    %   - RSF:          Skalierungsfaktor der Reflexionswerte
    %
    % Ausgabe
    %   - hist:         Histogramm
    %   - counter:      Pixelanzahl des segmentierten Untersuchungsgebiets

    hist                = zeros(1, RSF);
    [lines, samples, b] = size(img);
    counter             = 0;
    
    for y=1:lines
        for x=1:samples
            val     = round(img(y, x));
            valC    = round(imgRef(y, x));
            if(valC ~= -1) % ausschlielich selektiertes ROI  
                counter = counter +1;
                if(val > 0)
                    hist(val) = hist(val) + 1;                    
                end
            end           
        end
    end
end