function [imgNDSI] = getNDSI(data, WL)

    % Funktion
    %   Berechnung des NDSI fr alle Pixel in data.
    %
    % Eingabe
    %   - data:         Hyperspektraldaten
    %   - WL:           Wellenlngen der Spektralbnder
    %
    % Ausgabe:
    %   - imgNDSI:      NDSI-Auswertung
    
    [lines, samples, bands] = size(data);
    imgNDSI                 = zeros(lines, samples); 
        
    NIR_lim     = [0.85 0.87];
    SWIR_lim    = [1.63 1.65];
    
    NIR         = getSpecBands(data, WL, NIR_lim);
    SWIR        = getSpecBands(data, WL, SWIR_lim);
    
    for y=1:lines
        for x=1:samples
            imgNDSI(y, x) = (NIR(y, x) - SWIR(y, x))/(NIR(y, x) + SWIR(y, x));
        end
    end

end