function [imgNDVI] = getNDVI(data, WL)

    % Funktion
    %   Berechnung des NDVI fr alle Pixel in data.
    %
    % Eingabe
    %   - data:         Hyperspektraldaten
    %   - WL:           Wellenlngen der Spektralbnder
    %
    % Ausgabe:
    %   - imgNDVI:      NDVI-Auswertung
    
    [lines, samples, bands] = size(data);
    imgNDVI                 = zeros(lines, samples); 
    
    NIR_lim = [0.85 0.87];
    RED_lim = [0.65 0.67];
    
    NIR = getSpecBands(data, WL, NIR_lim);
    RED = getSpecBands(data, WL, RED_lim);
    
    for y=1:lines
        for x=1:samples
            imgNDVI(y, x) = (NIR(y, x) - RED(y, x))/(NIR(y, x) + RED(y, x));
        end
    end

end