function [bands] = getSpecBands(data, WL, bandLim)

    % Funktion
    %   Ermittlung der Spektralbnder, die dem Wellenlngenbereich 
    %   innerhalb der Grenzen bandLim entsprechen und Erzeugung einer
    %   korrespondierenden Bildmatrix. Im Fall mehrere Spektralbnder
    %   erfolgt eine Mittelung der Spektralwerte.
    %
    % Eingabe
    %   - data:         Hyperspektraldaten
    %   - WL:           Wellenlngen der Spektralbnder
    %   - bandLim:      Grenzen des gesuchten Wellenlngenbereichs
    %
    % Ausgabe:
    %   - bands:        Ausgabematrix des gesuchten Wellenlngenbereichs

    WL          = WL{:};
    bands_idx   = find(((WL > bandLim(1)) + (WL < bandLim(2))) > 1);
    bands       = 0;
    nob         = 0;
    for i=1:length(bands_idx)
        nob = nob +1;
        bands = bands + data(:, :, bands_idx(i));
    end
    bands = bands./nob;

end