function [imgTH] = thresholding(data, img, sw, RSF)

    % Funktion
    %   Schwellwertbildung des Eingabebildes. Der Schwellwert wird in
    %   Abhngigkeit des empirisch ermittelten Wertes sw und der 
    %   Gesamtgre des Untersuchungsgebiets bestimmt.
    % 
    % Eingabe
    %   - data:         Hyperspektraldaten
    %   - img:          Eingabebild    
    %   - sw:           Empirischer Wert zur Schwellwertberechnung
    %   - RSF:          Skalierungsfaktor der Reflexionswerte
    %
    % Ausgabe
    %   - imgTH:       Schwellwertbild (binr)

    [lines, samples, b] = size(img);
    imgRef              = data(:, :, 1);
    imgTH               = zeros(lines, samples);
    [hist, pixOfField]  = getHistogram(img, imgRef, RSF);
    idx                 = find(hist);
    estArea             = sw*pixOfField;
    sumPix              = 0;
    thresh              = 0;
    
    % Bestimmung des Schwellwerts
    hist2 = zeros(size(hist));
    for k=length(idx):-1:1
        sumPix = sumPix + hist(idx(k));
        hist2(idx(k)) = hist(idx(k));
        if(sumPix >= estArea)
           thresh = idx(k);
           break
        end    
    end
    
    % Schwellwertbildung    
    for y=1:lines
        for x=1:samples
             val = img(y, x);
             if(val > thresh)
                 imgTH(y, x) = 10000;
             end
        end
    end        

end