function [trackLines] = approxLines(trackLines, imgBW, trackGeom, GSD, dm)

    % Funktion
    %   Korrektur der Linienendpunkte zur besseren Annherung des
    %   tatschlichen Fahrgassenverlaufs.
    % 
    % Eingabe
    %   - trackLines:       Fahrgassenlinien
    %   - imgBW:            Binres Kantenbild
    %   - trackGeom:        Parameter des Fahrspurmodells
    %   - GSD:              Bodenauflsung
    %   - dm:               Bearbeitungsmodus
    %
    % Ausgabe
    %   - trackLines:       Fahrgassenlinien
    
    [lines, samples]    = size(imgBW);        
    coeffs              = getLineCoeffs(trackLines);
    imgRef              = zeros(lines, samples);
        
    % Gre der Pixelumgebung
    trackWidth = ceil(trackGeom(2)/GSD);
    if(mod(trackWidth, 2) == 0)
        N = trackWidth+1;
    else
        N = trackWidth+2;
    end
    n = (N-1)/2;
        
    for k=1:length(trackLines)        
        
        start   = trackLines(k).point1;
        stop    = trackLines(k).point2;
        theta0  = trackLines(k).theta;
        theta   = 90 - theta0;
        c       = coeffs{k};

        % Laufrichtung und Laufgrenzen
        if(abs(theta) > 45)
            % y-Richtung
            mode = 1;
            limS = min(start(2), stop(2));
            limE = max(start(2), stop(2));
        else
            % x-Richtung
            mode = 2;
            limS = min(start(1), stop(1));
            limE = max(start(1), stop(1));
        end
        
        % Linie entlang laufen
        xyLine = []; 
        for kk=limS:limE   
            if(mode==1)
                y = kk;
                x = round((y - c(2))/c(1));
            else
                x = kk;
                y = round(c(1)*x+c(2));           
            end
            
            % Innerhalb des Bildes?
            if(x-n >= 1 && x+n <= samples && y-n >= 1 && y+n <= lines)
                for j=-n:n
                    for i=-n:n
                        if(imgBW(y+j, x+i) ~= 0)
                            xyLine = [xyLine; x+i,y+j];
                            imgRef(y+j, x+i) = 1;
                        end
                    end
                end
            end
        end
        
        % Polyfit pro Linie        
        coefficients  = polyfit(xyLine(:, 1), xyLine(:, 2), 1);                
        x1 = linspace(min(xyLine(:, 1))+dm, max(xyLine(:, 1))-dm);        
        y1 = polyval(coefficients,x1);
        
        % Anpassung der Hough-Linien
        if(theta0 < 0)
            trackLines(k).point1 = round([x1(1) y1(1)]);
            trackLines(k).point2 = round([x1(end) y1(end)]);                       
        else
            trackLines(k).point1 = round([x1(end) y1(end)]);
            trackLines(k).point2 = round([x1(1) y1(1)]);            
        end
        
    end
end