function [trackLines] = correctLines(trackLines, imgGray, subset)

    % Funktion
    %   Korrektur der Fahrgassenlinien bezglich fehlerhaft detektierter
    %   Segmente. Mit Hilfe einer Extremwertanalyse werden mgliche Lcken
    %   entlang der Linien detektiert und beseitigt.
    % 
    % Eingabe
    %   - trackLines:       Fahrgassenlinien
    %   - imgGray           Grauwertbild
    %   - subset:           Subset-ID
    %
    % Ausgabe
    %   - trackLines:       Fahrgassenlinien    

    [lines, samples]    = size(imgGray);        
    coeffs              = getLineCoeffs(trackLines);
    filter              = [20 15 15];
    
    for k=1:length(trackLines)   
        
        start   = trackLines(k).point1;
        stop    = trackLines(k).point2;
        theta0  = trackLines(k).theta;
        theta   = 90 - theta0;
        c       = coeffs{k};
        
        idx = 0; lineVals = [];
                
        % Laufrichtung und Laufgrenzen
        if(abs(theta) > 45)
            % y-Richtung
            mode = 1;       
            limS = min(start(2), stop(2));
            limE = max(start(2), stop(2));
        else
            % x-Richtung
            mode = 2;
            limS = min(start(1), stop(1));
            limE = max(start(1), stop(1));
        end

        % Ermittlung des Grauwertprofils ---------------------------------
        for kk=limS:limE   
            if(mode==1)
                y = kk;
                x = round((y - c(2))/c(1));
            else
                x = kk;
                y = round(c(1)*x+c(2));           
            end

            % Innerhalb des Bildes?
            if(x >= 1 && x <= samples && y >= 1 && y <= lines)
                idx = idx +1;
                lineVals = [lineVals; idx x y imgGray(y, x)];
            end
        end        
        
        % Glttung des Grauwertprofils ----------------------------------- 
        lineValsMid = []; 
        n = round((size(lineVals, 1))/filter(subset));
        lineValsMid = lineVals(1:n, end);
        for i=1+n:size(lineVals, 1)-n
            sum = 0; num =0;
            for j=-n:n
                sum = sum + lineVals(i+j, end);
                num = num +1;
            end
            lineValsMid = [lineValsMid; sum/num];
        end        
        lineValsMid = [lineValsMid; lineVals(end-n+1:end, end)];        
        
        % Erste Ableitung des gegltteten Grauwertprofils ----------------
        lineDeriv = diff(lineValsMid);
        
        % Extremwertanalyse ----------------------------------------------
        xyNew = peakAnalysis(lineDeriv, lineVals, lineValsMid);
        
        % Anpassung der Hough-Linie --------------------------------------
        trackLines(k).point1 = xyNew(1, :);
        trackLines(k).point2 = xyNew(2, :);
        
    end
end