function [lines] = getHoughLines(img, numpeaks)

    % Funktion
    %   Hough-Transformation eines binren Eingabebildes und Extraktion
    %   geradliniger Strukturen.
    % 
    % Eingabe
    %   - img:          Eingabebild (binr)
    %   - numpeaks:     Maximale Anzahl zu detektierender Linien
    %
    % Ausgabe
    %   - lines:        Extrahierte Hough-Linien

    [H,T,R]     = hough(img);    
    P           = houghpeaks(H,numpeaks);
    lines       = houghlines(img,T,R,P);
    
    moreTracks  = 1;
    preNumOfHL  = length(lines);
    if(preNumOfHL > numpeaks), numpeaks = preNumOfHL-1; end
    
    while(moreTracks)        
        numpeaks    = numpeaks +1;
        P           = houghpeaks(H,numpeaks,'threshold',ceil(0.3*max(H(:))));
        lines       = houghlines(img,T,R,P); 
        numOfHL     = length(lines);
        if(numOfHL == preNumOfHL), moreTracks = 0; end     
        preNumOfHL = numOfHL;
    end          

end
