function [trackLines, alpha] = removeNoPrefLines(houghLines)

    % Funktion
    %   Entfernung der Hough-Linien, die nicht in Vorzugsrichtung liegen
    %   durch berprfung der Parameter des Strukturarrays.
    % 
    % Eingabe
    %   - houghLines:       Hough-Linien
    %
    % Ausgabe
    %   - trackLines:       Fahrgassenlinien
    %   - alpha:            Winkel der Vorzugsrichtung

    paramList   = getParamList(houghLines);
    alpha       = mode(paramList(:, 6));
    HLRest      = struct('point1', 0, 'point2', 0, 'theta', 0, 'rho', 0);

    numOfDelLines   = 0;
    nLine           = 0;
    for k=1:length(houghLines)   
        % Anpassung des Index
        kk      = k - numOfDelLines;    
        theta0  = houghLines(kk).theta;
        if(abs(theta0-alpha) > 1)
            nLine = nLine +1;
            HLRest(nLine) = houghLines(kk);
            houghLines(kk)  = [];
            numOfDelLines   = numOfDelLines +1;
        end
    end
    
    if(alpha < 0)
       alpha = -(90+alpha);
   else
       alpha = 90-alpha;
   end

   trackLines = houghLines;

end