function [intPointsCor] = adaptIntPoints(intPoints)

    % Funktion
    %   Entfernung von Schnittpunkten, die nicht als Paar einer Fahrspur
    %   auftreten oder aufgrund von Rundungsfehlern Dopplungen entsprechen.
    %
    % Eingabe
    %   - intPoints:    Schnittpunkte des Pixel-Quadrats
    %
    % Ausgabe
    %   - intPoints:    Schnittpunkte eines Pixel-Quadrats

    intPointsCor    = intPoints;
    trackIDs        = unique(intPoints(:, 3));

    delP = 0;

    % Pro Fahrspurlinie (track)
    for j=1:length(trackIDs)  
        % Indizes der daugehrigen Schnittpunkte
        numOfTr = find(intPoints(:, 3) == trackIDs(j));
        % Fallunterscheidung
        if(length(numOfTr) < 2)
            % Fahrspur mit einem Punkt
            intPointsCor(numOfTr - delP, :) = [];
            delP = delP +1;
        elseif(length(numOfTr) == 3)
            % Fahrspur mit drei Punkten            
            % Entfernung der fehlerhaften Punkte -------------------------    
            delP2 = 0;
            for o=1:length(numOfTr)
                oo = o - delP2;
               intPointsCor(numOfTr(oo)- delP, :) = []; 
               delP2 = delP2 +1;
            end
            % Anapssung der fehlerhaften Punkte --------------------------
            points  = intPoints(numOfTr(1):numOfTr(end), :);
            xU      = unique(points(:, 1));
            yU      = unique(points(:, 2));
            if(length(xU) < 3)
                for jj=1:length(xU)
                   xUidx = find(xU(jj) == points(:, 1) );
                   if(length(xUidx) == 2)
                       % Anpassung des Y-Wertes
                       points(xUidx(1), 2) = round((points(xUidx(1), 2)+points(xUidx(2), 2))/2);
                       points(xUidx(2), :) = [];
                   end
                end
            end            
            if(length(yU) < 3)
                for jj=1:length(yU)
                   yUidx = find(yU(jj) == points(:, 2) );
                   if(length(yUidx) == 2)
                       % Anpassung des X-Wertes
                       points(yUidx(1), 1) = round((points(yUidx(1), 1)+points(yUidx(2), 1))/2);
                       points(yUidx(2), :) = [];
                   end
                end
            end    
            delP = delP +1;
            intPointsCor = sortrows([intPointsCor; points], 3);
        end
    end    
    
end