function [intPointsF] = checkForCorners(intPoints, xyRect, rect, a)

    % Funktion
    %   berprft, ob die Ecken des Pixel-Quadrats Teil des Polygons zur
    %   Flchenberechnung sind
    %
    % Eingabe
    %   - intPoints:    Schnittpunkte des Pixel-Quadrats
    %   - xyRect:       Eckpunkte des Pixel-Quadrats
    %   - rect:         Parameter des Pixel-Quadrats der Form [x y width height]
    %   - a:            Winkel der Vorzugsrichtung
    %
    % Ausgabe
    %   - intPointsF:   Angepasste Schnittpunkte des Pixel-Quadrats
    
    intPointsF      = [];
    intPointsX      = [];
    intPointsY      = [];
    intPointsRest   = intPoints;
    hlid            = intPoints(1, 5);
    
    % Grenzwerte in X- und Y-Richtung
    xlim = [rect(1) rect(1)+rect(3)];
    ylim = [rect(2) rect(2)+rect(4)];

    for j=1:length(xlim)
        idxLimX = find((intPoints(:, 1) == xlim(j)));
        idxLimY = find((intPoints(:, 2) == ylim(j)));

        % Punkte auf einer Kante
        if(length(idxLimX) == 2)               
            idxLimX    = sort(idxLimX);
            % Entfernung der Punkte, weil irrelevant
            intPointsRest(idxLimX(1), :)    = [];           
            if(size(intPointsRest,1) == 1)
                intPointsRest(1, :)  = [];
            else 
                intPointsRest(idxLimX(2)-1, :)  = [];
            end
        end
        
        % Punkte auf einer Kante
        if(length(idxLimY) == 2)               
            idxLimY    = sort(idxLimY);
            intPointsRest(idxLimY(1), :)    = [];
            if(size(intPointsRest,1) == 1)
                intPointsRest(1, :)  = [];
            else 
                intPointsRest(idxLimY(2)-1, :)  = [];
            end
        end
        
    end
    
    if(~isempty(intPointsRest))        
        if(size(intPointsRest, 1) == 2)
            intPointsF  = intPoints;
            % Bestimmung der nhsten Ecke
            corner      = getCorner(intPointsRest, xyRect);
            intPointsF  = [intPointsF; corner];            
        else
            intPointsF  = intPoints;
            % Ergnzung der Ecken in Abhngigkeit des Winkels
            if(a > 0)
                intPointsF = [intPointsF; [xlim(1) ylim(2) -1 -1 hlid]];
                intPointsF = [intPointsF; [xlim(2) ylim(1) -1 -1 hlid]];
            else
                intPointsF = [intPointsF; [xlim(1) ylim(1) -1 -1 hlid]];
                intPointsF = [intPointsF; [xlim(2) ylim(2) -1 -1 hlid]];
            end            
            
        end
    else
        % keine Ecke innerhalb des Polygons
        intPointsF  = intPoints;
    end
   
    % Entfernung doppelter Eintrge (aufgrund von Rundungsfehlern)
    [intPointsF2 ia ic] = unique(intPointsF(:, 1:2), 'rows');
    icUnique = unique(ic);
    for i=1:length(icUnique)
        idx = find(icUnique(i) == ic(:));
        if(length(idx)>1)
            for j=1:length(idx)
               if(intPointsF(idx(j), 3) == -1)
                   intPointsF(idx(j), :) = [];
               end
            end
        end        
    end   
end
