function [part1, part2] = getAreaSegments6(intPoints, xyRect, rect, a)

    % Funktion
    %   Separation der Schnittpunkte pro Flche fr den Fall von 6
    %   Schnittpunkten und Ergnzung um Eckpunkte.
    %
    % Eingabe
    %   - intPoints:    Schnittpunkte des Pixel-Quadrats
    %   - xyRect:       Eckpunkte des Pixel-Quadrats
    %   - rect:         Parameter des Pixel-Quadrats der Form [x y width height]
    %   - a:            Winkel der Vorzugsrichtung
    %
    % Ausgabe
    %   - part1:        Schnitt- und Eckpunkte der ersten Flche
    %   - part2:        Schnitt- und Eckpunkte der zweiten Flche
        
    xlim = [rect(1) rect(1)+rect(3)];
    ylim = [rect(2) rect(2)+rect(4)];

    innerLines = [];
    outerLines = [];
    for ii=1:size(intPoints, 1)
       if(intPoints(ii, 4) == 0)
           innerLines = [innerLines; intPoints(ii, :)];
       else
           outerLines = [outerLines; intPoints(ii, :)];
       end
    end
    % immer 2 innere und 1 uere Linie
    midOuterLine    = (outerLines(1, 1:2) + outerLines(2, 1:2))/2;
    dist2Line       = [];
    for k=1:2:3        
        midInnerLine    = (innerLines(k, 1:2) + innerLines(k+1, 1:2))/2;
        curDist         = norm(midOuterLine - midInnerLine);       
        dist2Line       = [dist2Line, curDist];            
    end

    % (1) Fahrspur-Paar
    [minDist, idxMinDist] = min(dist2Line);
    if(idxMinDist == 2), idxMinDist = 3; end
    part1 = [outerLines; innerLines(idxMinDist:idxMinDist+1, :)];
    % Check: Ist eine Ecke des Rechtecks auch Teil des Polygons?
    part1  = checkForCorners(part1, xyRect, rect, a);

    % (2) Einzelne Fahrspur
    [maxDist, idxMaxDist] = max(dist2Line);
    if(idxMaxDist == 2), idxMaxDist = 3; end
    part2 = innerLines(idxMaxDist:idxMaxDist+1, :);
    % Detektion des nhsten Eckpunktes
    incCorner       = getCorner(part2, xyRect);
    part2  = [part2; incCorner];

end
