function [part1, part2] = getAreaSegments8(intPoints, xyRect, rect, tracks, a)

    % Funktion
    %   Separation der Schnittpunkte pro Flche fr den Fall von 8
    %   Schnittpunkten und Ergnzung um Eckpunkte.
    %
    % Eingabe
    %   - intPoints:    Schnittpunkte des Pixel-Quadrats
    %   - xyRect:       Eckpunkte des Pixel-Quadrats
    %   - rect:         Parameter des Pixel-Quadrats der Form [x y width height]
    %   - tracks:       Fahrspurlinien
    %   - a:            Winkel der Vorzugsrichtung
    %
    % Ausgabe
    %   - part1:        Schnitt- und Eckpunkte der ersten Flche
    %   - part2:        Schnitt- und Eckpunkte der zweiten Flche

    intLines = [];
    for i=1:size(intPoints, 1)-1
        if(intPoints(i, 3) == intPoints(i+1, 3))
            % [start1 stop1 start1 stop1 track-ID rho Position  HLID]
           line = [intPoints(i, 1:2), intPoints(i+1, 1:2), intPoints(i, 3), tracks(intPoints(i, 3)).rho, intPoints(i, 4), intPoints(1, 5)];
           intLines = [intLines; line];
        end            
    end        
    intLines = sortrows(intLines, 6);

    % xy kk pos hlid
    part1 = [intLines(1, 1:2) intLines(1, 5) intLines(1, 7:8); intLines(1, 3:4) intLines(1, 5) intLines(1, 7:8); ...
                      intLines(2, 1:2) intLines(2, 5) intLines(2, 7:8); intLines(2, 3:4) intLines(2, 5) intLines(2, 7:8)];
    part2 = [intLines(3, 1:2) intLines(3, 5) intLines(3, 7:8); intLines(3, 3:4) intLines(3, 5) intLines(3, 7:8); ...
                      intLines(4, 1:2) intLines(4, 5) intLines(4, 7:8); intLines(4, 3:4) intLines(4, 5) intLines(4, 7:8)];

    % Check: Ist eine Ecke des Rechtecks auch Teil des Polygons?
    part1 = checkForCorners(part1, xyRect, rect, a);
    part2 = checkForCorners(part2, xyRect, rect, a);
    
end