function [tracks] = getScaledTracks(trackLines, S, t1, t2)

    % Funktion
    %   Berechnung der Fahrspurlinien pro Fahrgasse in Abhngigkeit der
    %   Fahrspurparameter t1 und t2 sowie des Skalierungsfaktors S.
    % 
    % Eingabe
    %   - trackLines:       Fahrgassenlinien
    %   - S:                Skalierungsfaktor
    %   - t1:               Fahrspurbreite
    %   - t2:               Fahrspurabstand
    %
    % Ausgabe
    %   - tracks:           Fahrspurlinien    

    tracks  = struct('point1', 0, 'point2', 0, 'theta', 0, 'rho', 0, 'pos', 0, 'hlid', 0);
    nOT     = 0;
    pos     = 0;
    dm      = [(S-1)/2 (S-1)/2];
            
    for k = 1:length(trackLines)     
        start       = S*trackLines(k).point1-dm;        
        stop        = S*trackLines(k).point2-dm;
        theta0      = trackLines(k).theta;
        theta       = 90-theta0;
        rho         = trackLines(k).rho;

        % Verschiebung der Linie in Abhngigkeit des Winkels
        if(theta < 45)
            % Verschiebung in y-Richtung
            diffd = [0 (t2/2)/cosd(theta)];
            diffb = [0 (t2/2-t1)/cosd(theta)];
        else
            % Verschiebung in x-Richtung
            diffd = [(t2/2)/sind(theta) 0];
            diffb = [(t2/2-t1)/sind(theta) 0];
        end
        diffs = [diffd; diffb];

        for j=1:size(diffs, 1)
            if(j == 1)
                pos = 1;
            else
                pos = 0;
            end
            
            for i=-1:2:1                
                % Zhler Fahrspuren
                nOT                 = nOT + 1;
                startN              = round(start + i*diffs(j, :));
                stopN               = round(stop + i*diffs(j, :));
                tracks(nOT).point1  = startN;
                tracks(nOT).point2  = stopN;
                tracks(nOT).theta   = theta0;
                tracks(nOT).rho     = rho+i*norm(diffs(j, :));
                tracks(nOT).pos     = pos;
                tracks(nOT).hlid    = k;
            end
        end
    end

end