function [interXY] = interLineRect(track, rect, kk)

    % Funktion
    %   Berechnung der Schnittpunkte einer Fahrspur mit einem 
    %   Pixel-Quadrat.
    %
    % Eingabe
    %   - track:    Fahrspurlinie
    %   - rect:     Parameter des Pixel-Quadrats der Form [x y width height]
    %   - kk:       ID der Fahrspur
    %
    % Ausgabe
    %   - interXY:  Liste der Schnittpunkte der Form [x y kk pos]
    
    interXY = [];
    
    % Fahrspur-Parameter
    start   = track.point1;
    stop    = track.point2;
    pos     = track.pos;
    hlid    = track.hlid;
    
    % Grenzwerte in X- und Y-Richtung
    xlim    = [rect(1) rect(1)+rect(3)];
    ylim    = [rect(2) rect(2)+rect(4)];
    
    % Berechnung der Koeffizienten des linearen Polynoms
    xx      = [start(1) stop(1)];
    yy      = [start(2) stop(2)];
    c       = polyfit(xx, yy, 1);   

    % Schnittpunkte mit Rechteck bzw. mit allen 4 Grenzwerten = Kanten
    interXY0 = [];
    for i=1:length(xlim)
        yP          = round(c(1)*xlim(i)+c(2));     
        xP          = round((ylim(i) - c(2))/c(1));           
        interXY0    = [interXY0; xlim(i) yP; xP ylim(i)];
    end
    
    % Auswertung der Schnittpunkte
    for k=1:size(interXY0, 1)
        xy = interXY0(k, :);
        % Innerhalb der Geraden?
        if(xy(1) >= min(xx) && xy(1) <= max(xx) && xy(2) >= min(yy) && xy(2) <= max(yy))
            % Innerhalb des Rechtecks
            if(xy(1) >= xlim(1) && xy(1) <= xlim(2) && xy(2) >= ylim(1) && xy(2) <= ylim(2))
                % Schnittpunkt track-ID Position in der Trasse Houghline-ID
                interXY = [interXY; [xy kk pos hlid]];
            end
        end
    end   
    
    % Entfernung doppelter Eintrge (aufgrund von Rundungsfehlern)
    interXY = unique(interXY, 'rows');
    
end