function [outlier, pixSpec] = analyzePixEnv(data, curVeg, WL, mask, p)

    % Funktion
    %   Analyse der Pixelumgebung zur Detektion von Ausreiern anhand des 
    %   Spectral Angle Mapper.
    % 
    % Eingabe
    %   - data:         Hyperspektraldaten
    %   - curVeg:       Detektiertes Bestandspixel
    %   - WL:           Wellenlngen der Spektralbnder
    %   - mask:         Analyseumgebung
    %   - p:            Flag zum Plotten (1 = ja, 0 = nein)
    %
    % Ausgabe
    %   - outlier:      Flag zur Kennzeichnung eines Ausreiers
    %   - pixSpec:      Pixelspektrum des Bestandspixels


    [mH, mW, mB]    = size(mask);
    mC              = round(mH/2);
    mCC             = mC-1;
    outlier         = 0;
    
    dataPatch = data(curVeg(1)-mCC:curVeg(1)+mCC, curVeg(2)-mCC:curVeg(2)+mCC, :);
    
    if(p)
        for ii=-mCC:mCC
            for jj=-mCC:mCC
                if(mask(mC+jj, mC+ii) ~= 0)
                    plot(curVeg(2)+ii, curVeg(1)+jj, 'o', 'LineWidth', 5, 'Color', 'y')
                end
            end
        end
    end
    
    % NDVI
    NDVI                    = getNDVI(dataPatch, WL);
    NDVImask                = zeros(size(NDVI));
    NDVImask(find(mask))    = NDVI(find(mask));
    
    % Maximaler NDVI = Referenzpixel
    [maxNDVI, maxID]        = max(NDVImask(:));
    [refY,refX]             = ind2sub(size(NDVImask),maxID);
    diff2Center             = [refY, refX] - [mC, mC];
    dataXY                  = curVeg + diff2Center;

    % SAM des aktuellen Bestandspixels zum Referenzpixel
    refSpec     = squeeze(data(dataXY(1), dataXY(2), :));
    pixSpec     = squeeze(data(curVeg(1), curVeg(2), :));
    SAM         = acos((dot(refSpec, pixSpec))/(norm(refSpec)*norm(pixSpec)));

    if(SAM > 0.05)
        if(p), plot(curVeg(2), curVeg(1), 'x', 'LineWidth', 2, 'Color', 'r'), end
        outlier = 1;
    else
        outlier = 0;        
    end

end