function [missingPixIdxNew, imgVeg, imgTrack] = checkFirstIndices(missingPixIdx, lineVals, imgVeg, imgTrack)

    % Funktion
    %   Detektion und Behandlung eines oder mehrerer fehlender 
    %   Referenzspektren am Anfang der Linie.   
    % 
    % Eingabe    
    %   - missingPixIdx:        Indizes fehlender Referenzspektren
    %   - lineVals:             Linienparameter
    %   - imgVeg:               Matrix der Bestandsreferenzspektren
    %   - imgTrack:             Matrix der Flchenabschtzung
    %
    % Ausgabe
    %   - missingPixIdxNew:     Angepasste Indizes fehlender Referenzspektren
    %   - imgVeg:               Matrix der Bestandsreferenzspektren
    %   - imgTrack:             Matrix der Flchenabschtzung

    % Check for group
    idxGroup = []; missingPixIdxNew = [];group = 1;
    
    for i=1:length(missingPixIdx)-1
        if(missingPixIdx(i+1)-missingPixIdx(i) == 1)
            if(group)
                idxGroup    = [idxGroup missingPixIdx(i) missingPixIdx(i+1)];
                pause
            end
        else
            group = 0;
        end
    end    
    idxGroup = unique(idxGroup);
    
    if(~isempty(idxGroup))
        missingPixIdxNew = missingPixIdx(idxGroup(end)+1:end);
    else
        missingPixIdxNew = missingPixIdx(2:end);
        idxGroup = 1;
    end
    
    % Entfernen der ersten Pixel
    for j=1:length(idxGroup)
        xy                          = lineVals(idxGroup(j), 1:2);
        imgVeg(xy(1), xy(2), :)     = 0;
        imgTrack(xy(1), xy(2))  = 0;       
    end

end