function [missingPixIdxNew, imgVeg, imgTrack] = checkLastIndices(missingPixIdx, lineVals, imgVeg, imgTrack)

    % Funktion
    %   Detektion und Behandlung eines oder mehrerer fehlender 
    %   Referenzspektren am Ende der Linie.   
    % 
    % Eingabe    
    %   - missingPixIdx:        Indizes fehlender Referenzspektren
    %   - lineVals:             Linienparameter
    %   - imgVeg:               Matrix der Bestandsreferenzspektren
    %   - imgTrack:             Matrix der Flchenabschtzung
    %
    % Ausgabe
    %   - missingPixIdxNew:     Angepasste Indizes fehlender Referenzspektren
    %   - imgVeg:               Matrix der Bestandsreferenzspektren
    %   - imgTrack:             Matrix der Flchenabschtzung
    
    % Check for group
    idxGroup = []; missingPixIdxNew = [];group = 1;
    
    for i=length(missingPixIdx):-1:2
        if(missingPixIdx(i)-missingPixIdx(i-1) == 1)
            if(group)
                idxGroup    = [idxGroup missingPixIdx(i) missingPixIdx(i-1)];
            end
        else
            group = 0;
        end        
    end   
    
    idxGroup            = unique(idxGroup);    
    missingPixIdxNew    = missingPixIdx(1:end-length(idxGroup));
    
    % Entfernen der letzten Pixel
    for j=1:length(idxGroup)
        xy                          = lineVals(idxGroup(j), 1:2);
        imgVeg(xy(1), xy(2), :)     = 0;
        imgTrack(xy(1), xy(2))  = 0;       
    end
end