function [mask] = getMask(midLineDist, alpha, estTrackWidth)

    % Funktion
    %   Bestimmung der Analyseumgebung in Abhngigkeit des mittleren
    %   Fahrgassenabstands und der geschtzten Fahrgassenbreite.
    % 
    % Eingabe    
    %   - midLineDist:      Mittlerer Fahrgassenabstand
    %   - alpha:            Winkel der Vorzugsrichtung
    %   - estTrackWidth:    Geschtzte Fahrgassenbreite
    %
    % Ausgabe
    %   - mask:             Analyseumgebung

    alpha   = -(90-alpha);
    b       = midLineDist*2+1;
    c       = ceil(b/2);
    m       = zeros(b, b);    
    
    if(mod(midLineDist, 2))
        % Pixelanzahl zwischen Trassen = ungerade
        d   = midLineDist - 2*estTrackWidth -2 -2; 
        if(d < 0)
            m(:, c:c) = 1;
            win = 1;
        elseif(d ==1)
            m(:, c-1:c) = 1;
            win = 2*d;
        else
            hd  = (d-1)/2;
            m(:, c-hd:c+hd) = 1;
            win = d-1;
        end
        
        mRot = imrotate(m, alpha, 'crop');
        mask = mRot(c-win:c+win, c-win:c+win);    
                
    else
        % Pixelanzahl zwischen Trassen = gerade    
        d = midLineDist - 2*estTrackWidth -2 -3;
        if(d < 0)
            m(:, c:c) = 1;
            win = 1;
        elseif(d ==1)
            m(:, c-1:c) = 1;
            win = 2*d;
        else
            hd  = (d-1)/2;
            m(:, c-hd:c+hd) = 1;
            win = d-1;
        end
        
        mRot = imrotate(m, alpha, 'crop');
        mask = mRot(c-win:c+win, c-win:c+win);
        
    end

end