function [imgVeg, imgTrack] = interpolateGaps(lineVals, missingPixIdx, imgVeg, imgTrack)

    % Funktion
    %   Interpolation mglicher Lcken anhand der benachbarten 
    %   Referenzspektren.
    % 
    % Eingabe
    %   - lineVals:         Linienparameter
    %   - missingPixIdx:    Indizes fehlender Referenzspektren
    %   - imgVeg:           Matrix der Bestandsreferenzspektren
    %   - imgTrack:         Matrix der Flchenabschtzung
    %
    % Ausgabe
    %   - imgVeg:           Matrix der Bestandsreferenzspektren
    %   - imgTrack:         Matrix der Flchenabschtzung

    idxGroup = [];
    group = 0;    
    
    % Check first Indices
    if(missingPixIdx(1) == 1)
        [missingPixIdx, imgVeg, imgTrack] = checkFirstIndices(missingPixIdx, lineVals, imgVeg, imgTrack);
    end
        
    % Check last Indices
    if(missingPixIdx(end) == size(lineVals, 1))
        [missingPixIdx, imgVeg, imgTrack] = checkLastIndices(missingPixIdx, lineVals, imgVeg, imgTrack);
    end
        
    for i=1:length(missingPixIdx)-1
        if(missingPixIdx(i+1)-missingPixIdx(i) == 1)                
            if(~group)
                idxGroup    = [idxGroup missingPixIdx(i)];
                group       = 1;
            else
                idxGroup    = [idxGroup missingPixIdx(i)];             
            end
        else
            if(group)
                idxGroup    = [idxGroup missingPixIdx(i)];
                % Interpolation fr die Gruppe
                xy1 = lineVals(idxGroup(1)-1, 1:2);
                xy2 = lineVals(idxGroup(end)+1,1:2);
                if(~isempty(imgVeg(xy1(1), xy1(2), :)))
                    if(~isempty(imgVeg(xy2(1), xy2(2), :)))
                        intSpec = (imgVeg(xy1(1), xy1(2), :) + imgVeg(xy2(1), xy2(2), :))/2;
                        for j=1:length(idxGroup)
                            xy = lineVals(idxGroup(j), 1:2);
                            imgVeg(xy(1), xy(2), :)     = intSpec;
                        end  
                        group = 0;
                    else
                        disp('Fehler')
                        pause
                    end
                else
                    disp('Fehler')
                    pause
                end

            else
                % Interpolation zwischen benachbarten Spektren
                xy  = lineVals(missingPixIdx(i), 1:2);
                xy1 = lineVals(missingPixIdx(i)-1, 1:2);
                xy2 = lineVals(missingPixIdx(i)+1,1:2);
                if(~isempty(imgVeg(xy1(1), xy1(2), :)))
                    if(~isempty(imgVeg(xy2(1), xy2(2), :)))
                        intSpec = (imgVeg(xy1(1), xy1(2), :) + imgVeg(xy2(1), xy2(2), :))/2;
                        imgVeg(xy(1), xy(2), :)     = intSpec;
                    else
                        disp('Fehler')
                        pause
                    end
                else
                    disp('Fehler')
                    pause
                end
            end                
        end      
    end
    if(group)
        idxGroup    = [idxGroup missingPixIdx(end)];
        % Interpolation fr die Gruppe
        xy1 = lineVals(idxGroup(1)-1, 1:2);
        xy2 = lineVals(idxGroup(end)+1,1:2);
        if(~isempty(imgVeg(xy1(1), xy1(2), :)))
            if(~isempty(imgVeg(xy2(1), xy2(2), :)))
                intSpec = (imgVeg(xy1(1), xy1(2), :) + imgVeg(xy2(1), xy2(2), :))/2;
                for j=1:length(idxGroup)
                    xy = lineVals(idxGroup(j), 1:2);
                    imgVeg(xy(1), xy(2), :)     = intSpec;
                end 
            else
                disp('Fehler')
                pause
            end
        else
            disp('Fehler')
            pause
        end
    else
        xy  = lineVals(missingPixIdx(end), 1:2);
        xy1 = lineVals(missingPixIdx(end)-1, 1:2);
        xy2 = lineVals(missingPixIdx(end)+1,1:2);
        if(~isempty(imgVeg(xy1(1), xy1(2), :)))
            if(~isempty(imgVeg(xy2(1), xy2(2), :)))
                intSpec = (imgVeg(xy1(1), xy1(2), :) + imgVeg(xy2(1), xy2(2), :))/2;
                imgVeg(xy(1), xy(2), :)     = intSpec;
            else
                disp('Fehler')
                pause
            end
        else
            disp('Fehler')
            pause
        end
    end

end